( cd usr/lib ; rm -rf libosgDB.so )
( cd usr/lib ; ln -sf libosgDB.so.25 libosgDB.so )
( cd usr/lib ; rm -rf libosgShadow.so.25 )
( cd usr/lib ; ln -sf libosgShadow.so.2.2.0 libosgShadow.so.25 )
( cd usr/lib ; rm -rf libosg.so )
( cd usr/lib ; ln -sf libosg.so.25 libosg.so )
( cd usr/lib ; rm -rf libosgText.so )
( cd usr/lib ; ln -sf libosgText.so.25 libosgText.so )
( cd usr/lib ; rm -rf libosgTerrain.so )
( cd usr/lib ; ln -sf libosgTerrain.so.25 libosgTerrain.so )
( cd usr/lib ; rm -rf libosgShadow.so )
( cd usr/lib ; ln -sf libosgShadow.so.25 libosgShadow.so )
( cd usr/lib ; rm -rf libosgUtil.so.25 )
( cd usr/lib ; ln -sf libosgUtil.so.2.2.0 libosgUtil.so.25 )
( cd usr/lib ; rm -rf libosg.so.25 )
( cd usr/lib ; ln -sf libosg.so.2.2.0 libosg.so.25 )
( cd usr/lib ; rm -rf libosgSim.so )
( cd usr/lib ; ln -sf libosgSim.so.25 libosgSim.so )
( cd usr/lib ; rm -rf libosgViewer.so )
( cd usr/lib ; ln -sf libosgViewer.so.25 libosgViewer.so )
( cd usr/lib ; rm -rf libOpenThreads.so.9 )
( cd usr/lib ; ln -sf libOpenThreads.so.2.2.0 libOpenThreads.so.9 )
( cd usr/lib ; rm -rf libosgParticle.so )
( cd usr/lib ; ln -sf libosgParticle.so.25 libosgParticle.so )
( cd usr/lib ; rm -rf libosgFX.so.25 )
( cd usr/lib ; ln -sf libosgFX.so.2.2.0 libosgFX.so.25 )
( cd usr/lib ; rm -rf libosgManipulator.so.25 )
( cd usr/lib ; ln -sf libosgManipulator.so.2.2.0 libosgManipulator.so.25 )
( cd usr/lib ; rm -rf libosgUtil.so )
( cd usr/lib ; ln -sf libosgUtil.so.25 libosgUtil.so )
( cd usr/lib ; rm -rf libOpenThreads.so )
( cd usr/lib ; ln -sf libOpenThreads.so.9 libOpenThreads.so )
( cd usr/lib ; rm -rf libosgManipulator.so )
( cd usr/lib ; ln -sf libosgManipulator.so.25 libosgManipulator.so )
( cd usr/lib ; rm -rf libosgGA.so )
( cd usr/lib ; ln -sf libosgGA.so.25 libosgGA.so )
( cd usr/lib ; rm -rf libosgTerrain.so.25 )
( cd usr/lib ; ln -sf libosgTerrain.so.2.2.0 libosgTerrain.so.25 )
( cd usr/lib ; rm -rf libosgFX.so )
( cd usr/lib ; ln -sf libosgFX.so.25 libosgFX.so )
( cd usr/lib ; rm -rf libosgGA.so.25 )
( cd usr/lib ; ln -sf libosgGA.so.2.2.0 libosgGA.so.25 )
( cd usr/lib ; rm -rf libosgSim.so.25 )
( cd usr/lib ; ln -sf libosgSim.so.2.2.0 libosgSim.so.25 )
( cd usr/lib ; rm -rf libosgViewer.so.25 )
( cd usr/lib ; ln -sf libosgViewer.so.2.2.0 libosgViewer.so.25 )
( cd usr/lib ; rm -rf libosgParticle.so.25 )
( cd usr/lib ; ln -sf libosgParticle.so.2.2.0 libosgParticle.so.25 )
( cd usr/lib ; rm -rf libosgDB.so.25 )
( cd usr/lib ; ln -sf libosgDB.so.2.2.0 libosgDB.so.25 )
( cd usr/lib ; rm -rf libosgText.so.25 )
( cd usr/lib ; ln -sf libosgText.so.2.2.0 libosgText.so.25 )
